/**
 * @file
 * Drupal behavior for the edit_ui blocks.
 */

(function (Drupal, $) {
  "use strict";

  /**
   * Drupal edit_ui block behavior.
   */
  Drupal.behaviors.editUiBlock = {
    attach: function (context, settings) {
      if (!this.isInitialized) {
        this.isInitialized = true;
        var collection;
        var model;

        // Init block collection.
        collection = Drupal.editUiBlock.collections.blockCollection = new Drupal.editUiBlock.BlockCollection();

        // Init block views.
        Drupal.editUiBlock.views.bodyVisualView = new Drupal.editUiBlock.BodyVisualView({
          collection: collection
        });

        // Init block view list.
        Drupal.editUiBlock.views.blockVisualViews = [];
        Drupal.editUiBlock.views.ghostBlockVisualViews = [];
        Drupal.editUiBlock.views.blockTooltipVisualViews = [];

        // Global variable for new block.
        Drupal.editUiBlock.models.newBlockModel = null;

        // Init dragging block model and view.
        model = Drupal.editUiBlock.models.draggingBlockModel = new Drupal.editUiBlock.DraggingBlockModel();
        Drupal.editUiBlock.views.draggingBlockVisualView = new Drupal.editUiBlock.DraggingBlockVisualView({
          model: model,
          el: $('#edit-ui__dragging')
        });
        Drupal.editUiBlock.views.ghostBlockVisualView = new Drupal.editUiBlock.GhostBlockVisualView({
          model: model,
          el: $(Drupal.theme('editUiGhostBlock'))
        });

        // Init tooltip fence.
        Drupal.editUiBlock.elements.editUiTooltipFence = $(Drupal.theme('editUiTooltipFence'));
        Drupal.editUiBlock.elements.editUiTooltipFence.appendTo('body');
      }
    }
  };

  /**
   * edit_ui block Backbone objects.
   */
  Drupal.editUiBlock = {
    // A hash of View instances.
    views: {},
    // A hash of Collection instances.
    collections: {},
    // A hash of Model instances.
    models: {},
    // A hash of jQuery elements.
    elements: {}
  };

  /**
   * Add new AJAX command called after the block as been created in the backend.
   */
  Drupal.AjaxCommands.prototype.editUiAddNewBlock = function (ajax, response, status) {
    if (Drupal.editUiBlock.models.newBlockModel instanceof Drupal.editUiBlock.BlockModel) {
      Drupal.editUiBlock.models.newBlockModel.set({
        id: response['id'],
        plugin_id: response['plugin_id'],
        label: response['label'],
        status: response['status'],
        html_id: response['html_id'],
        provider: response['provider']
      });
      Drupal.editUiBlock.views.bodyVisualView.initBlock(
        Drupal.editUiBlock.models.newBlockModel,
        $(response.content)
      );
      Drupal.editUiBlock.models.newBlockModel = null;
    }
  };

})(Drupal, jQuery);
