/**
 * @file
 * Provides theme functions for all of Edit UI's client-side HTML.
 */

(function (Drupal, $) {
  "use strict";

  /**
   * Wrapper block template.
   *
   * @param Object settings
   *   An object containing the block attributes.
   * @param string content
   *   The content to be wrapped.
   *
   * @return String
   *   A string representing a DOM fragment.
   */
  Drupal.theme.editUiWrapperBlock = function (settings, content) {
    return '' +
      '<div id="' + settings.html_id + '" class="edit-ui__block edit-ui__placeholder-block js-edit-ui__' + settings.plugin_id + '">' +
        content +
      '</div>';
  };

  /**
   * Placeholder block template.
   *
   * @param Object settings
   *   An object containing the block attributes.
   *
   * @return String
   *   A string representing a DOM fragment.
   */
  Drupal.theme.editUiPlaceholderBlock = function (settings) {
    return '' +
      '<div id="block-' + settings.id + '" class="block block-' + settings.provider + '">' +
        '<h2>' + settings.label + '</h2>' +
      '</div>';
  };

  /**
   * Ghost block template.
   *
   * @return String
   *   A string representing a DOM fragment.
   */
  Drupal.theme.editUiGhostBlock = function () {
    return '<div class="edit-ui__ghost"></div>';
  };

  /**
   * Disabled block template.
   *
   * @param Object settings
   *   An object containing the block attributes.
   *
   * @return String
   *   A string representing a DOM fragment.
   */
  Drupal.theme.editUiDisabledBlock = function (settings) {
    return '<a href="#" class="edit-ui__toolbar__link">' + settings.label + '</a>';
  };

  /**
   * Tooltip template.
   *
   * @param Object settings
   *   An object containing the block attributes.
   *
   * @return String
   *   A string representing a DOM fragment.
   */
  Drupal.theme.editUiTooltip = function (settings) {
    return '' +
      '<div class="edit-ui__tooltip js-edit-ui__tooltip quickedit quickedit-toolbar-container clearfix">' +
        '<i class="quickedit-toolbar-pointer"></i>' +
        '<div class="quickedit-toolbar-content">' +
          '<div class="quickedit-toolbar quickedit-toolbar-entity clearfix">' +
            '<div class="quickedit-toolbar-label">' + settings.label + ' (' + settings.id + ')</div>' +
          '</div>' +
        '</div>' +
        '<div class="quickedit-toolbar-lining"></div>' +
      '</div>';
  };

  /**
   * Element defining a containing box for the placement of the tooltip.
   *
   * @return String
   *   A string representing a DOM fragment.
   */
  Drupal.theme.editUiTooltipFence = function (settings) {
    return '<div class="edit-ui__tooltip-fence"></div>';
  };

})(Drupal, jQuery);
